@@ -36,6 +36,7 @@ public:
 
     void setAutoAddTransfers(bool enabled);
     void setAutoFillTransfers(bool enabled);
+    void setDownloadAssetsEnabled(bool enabled);
 
     /** Returns the transfer for reservation @p resId with @p alignment. */
     Transfer transfer(const QString &resId, Transfer::Alignment alignment) const;
@@ -57,7 +58,9 @@ public:
     /** Create a JourneyRequest for a given @p transfer. */
     Q_INVOKABLE KPublicTransport::JourneyRequest journeyRequestForTransfer(const Transfer &transfer) const;
 
+    // importing/syncing, not for the use in the UI, see e.g. discardTransfer above instead
     void importTransfer(const Transfer &transfer);
+    void removeTransfer(const QString &batchId, Transfer::Alignment alignment);
 
     // for unit tests only
     void overrideCurrentDateTime(const QDateTime &dt);
@@ -118,6 +121,7 @@ private:
     QDateTime m_nowOverride;
     bool m_autoAddTransfers = true;
     bool m_autoFillTransfers = false;
+    bool m_downloadAssets = false;
 };
 
 #endif // TRANSFERMANAGER_H
